# -*- coding: utf-8 -*-
import sys

if sys.version_info.major < 3:
    print("This program requires Python 3 and above to run.")
    sys.exit(1)

__codename__ = "Zaniest Zapper"
